Class: Google::Apis::AssuredworkloadsV1::AssuredworkloadsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AssuredworkloadsV1::AssuredworkloadsService
- Defined in:
- lib/google/apis/assuredworkloads_v1/service.rb
Overview
Assured Workloads API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://assuredworkloads.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse
Acknowledges an existing violation.
-
#analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse
Analyzes a hypothetical move of a source resource to a target workload to surface compliance risks.
-
#apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
This endpoint creates a new operation to apply the given update.
-
#archive_assuredworkload_resource_events(google_cloud_assuredworkloads_v1_archive_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ArchiveResourceEventsResponse
Finds orphan ResourceEvents matching the criteria and moves them to the ArchivedResourceEvents table.
-
#batch_organization_location_workload_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations.
-
#create_organization_location_workload(parent, google_cloud_assuredworkloads_v1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
Creates Assured Workload.
-
#delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleProtobufEmpty
Deletes the workload.
-
#enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse
This endpoint enables Assured Workloads service to offer compliance updates for the folder based assured workload.
-
#enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse
Enable resource violation monitoring for a workload.
-
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
Gets Assured Workload associated with a CRM Node.
-
#get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation
Retrieves Assured Workload Violation based on ID.
-
#initialize ⇒ AssuredworkloadsService
constructor
A new instance of AssuredworkloadsService.
-
#list_folder_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse
Lists the finding summary by category for a given scope.
-
#list_organization_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse
Lists the finding summary by category for a given scope.
-
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse
This endpoint lists all updates for the given workload.
-
#list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListViolationsResponse
Lists the Violations in the AssuredWorkload Environment.
-
#list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadsResponse
Lists Assured Workloads under a CRM Node.
-
#list_project_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse
Lists the finding summary by category for a given scope.
-
#mutate_organization_location_workload_partner_permissions(name, google_cloud_assuredworkloads_v1_mutate_partner_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
Update the permissions settings for an existing partner workload.
-
#patch_organization_location_workload(name, google_cloud_assuredworkloads_v1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
Updates an existing workload.
-
#restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse
Restrict the list of resources allowed in the Workload environment.
-
#revert_assuredworkload_archived_resource_events(google_cloud_assuredworkloads_v1_revert_archived_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
Finds matching ArchivedResourceEvents and moves them back to the ResourceEvents table.
Constructor Details
#initialize ⇒ AssuredworkloadsService
Returns a new instance of AssuredworkloadsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-assuredworkloads_v1', client_version: Google::Apis::AssuredworkloadsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse
Acknowledges an existing violation. By acknowledging a violation, users acknowledge the existence of a compliance violation in their workload and decide to ignore it due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted.
773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 773 def acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:acknowledge', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest::Representation command.request_object = google_cloud_assuredworkloads_v1_acknowledge_violation_request_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse
Analyzes a hypothetical move of a source resource to a target workload to surface compliance risks. The analysis is best effort and is not guaranteed to be exhaustive.
325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 325 def analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+target}:analyzeWorkloadMove', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse command.params['target'] = target unless target.nil? command.query['assetTypes'] = asset_types unless asset_types.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['project'] = project unless project.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
This endpoint creates a new operation to apply the given update.
698 699 700 701 702 703 704 705 706 707 708 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 698 def apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:apply', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest::Representation command.request_object = google_cloud_assuredworkloads_v1_apply_workload_update_request_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#archive_assuredworkload_resource_events(google_cloud_assuredworkloads_v1_archive_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ArchiveResourceEventsResponse
Finds orphan ResourceEvents matching the criteria and moves them to the ArchivedResourceEvents table.
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 74 def archive_assuredworkload_resource_events(google_cloud_assuredworkloads_v1_archive_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/assuredworkloads:archiveResourceEvents', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ArchiveResourceEventsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1_archive_resource_events_request_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ArchiveResourceEventsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ArchiveResourceEventsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#batch_organization_location_workload_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1BatchAcknowledgeViolationsResponse
Acknowledges multiple existing violations. By acknowledging violations, users acknowledge the existence of compliance violations in their workload and decide to ignore them due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted. This is a batch version of AcknowledgeViolation.
811 812 813 814 815 816 817 818 819 820 821 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 811 def batch_organization_location_workload_violation_acknowledge_violations(parent, google_cloud_assuredworkloads_v1_batch_acknowledge_violations_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/violations:batchAcknowledgeViolations', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1BatchAcknowledgeViolationsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1_batch_acknowledge_violations_request_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1BatchAcknowledgeViolationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1BatchAcknowledgeViolationsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_workload(parent, google_cloud_assuredworkloads_v1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
Creates Assured Workload.
366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 366 def create_organization_location_workload(parent, google_cloud_assuredworkloads_v1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/workloads', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation command.request_object = google_cloud_assuredworkloads_v1_workload_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['externalId'] = external_id unless external_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleProtobufEmpty
Deletes the workload. Make sure that workload's direct children are already in a deleted state, otherwise the request will fail with a FAILED_PRECONDITION error. In addition to assuredworkloads.workload.delete permission, the user should also have orgpolicy.policy.set permission on the deleted folder to remove Assured Workloads OrgPolicies.
407 408 409 410 411 412 413 414 415 416 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 407 def delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse
This endpoint enables Assured Workloads service to offer compliance updates
for the folder based assured workload. It sets up an Assured Workloads Service
Agent, having permissions to read compliance controls (for example: Org
Policies) applied on the workload. The caller must have resourcemanager.
folders.getIamPolicy and resourcemanager.folders.setIamPolicy permissions
on the assured workload folder.
444 445 446 447 448 449 450 451 452 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 444 def enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v1/{+name}:enableComplianceUpdates', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse
Enable resource violation monitoring for a workload.
475 476 477 478 479 480 481 482 483 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 475 def enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enableResourceMonitoring', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
223 224 225 226 227 228 229 230 231 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 223 def get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
Gets Assured Workload associated with a CRM Node
508 509 510 511 512 513 514 515 516 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 508 def get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation
Retrieves Assured Workload Violation based on ID.
845 846 847 848 849 850 851 852 853 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 845 def get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse
Lists the finding summary by category for a given scope.
146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 146 def list_folder_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dbFindingSummaries', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse
Lists the finding summary by category for a given scope.
189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 189 def list_organization_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dbFindingSummaries', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 268 def list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse
This endpoint lists all updates for the given workload.
735 736 737 738 739 740 741 742 743 744 745 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 735 def list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/updates', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListViolationsResponse
Lists the Violations in the AssuredWorkload Environment. Callers may also
choose to read across multiple Workloads as per AIP-159 by using '-' (the hyphen or dash character) as a wildcard character
instead of workload-id in the parent. Format organizations/org_id/locations/
location/workloads/-
892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 892 def list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/violations', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListViolationsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListViolationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['interval.endTime'] = interval_end_time unless interval_end_time.nil? command.query['interval.startTime'] = interval_start_time unless interval_start_time.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadsResponse
Lists Assured Workloads under a CRM Node.
548 549 550 551 552 553 554 555 556 557 558 559 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 548 def list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/workloads', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse
Lists the finding summary by category for a given scope.
938 939 940 941 942 943 944 945 946 947 948 949 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 938 def list_project_location_db_finding_summaries(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dbFindingSummaries', ) command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#mutate_organization_location_workload_partner_permissions(name, google_cloud_assuredworkloads_v1_mutate_partner_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
Update the permissions settings for an existing partner workload. For force updates don't set etag field in the Workload. Only one update operation per workload can be in progress.
585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 585 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}:mutatePartnerPermissions', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_workload(name, google_cloud_assuredworkloads_v1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
Updates an existing workload. Currently allows updating of workload display_name and labels. For force updates don't set etag field in the Workload. Only one update operation per workload can be in progress.
623 624 625 626 627 628 629 630 631 632 633 634 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 623 def patch_organization_location_workload(name, google_cloud_assuredworkloads_v1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation command.request_object = google_cloud_assuredworkloads_v1_workload_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse
Restrict the list of resources allowed in the Workload environment. The current list of allowed products can be found at https://cloud.google.com/ assured-workloads/docs/supported-products In addition to assuredworkloads. workload.update permission, the user should also have orgpolicy.policy.set permission on the folder resource to use this functionality.
664 665 666 667 668 669 670 671 672 673 674 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 664 def restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:restrictAllowedResources', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest::Representation command.request_object = google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revert_assuredworkload_archived_resource_events(google_cloud_assuredworkloads_v1_revert_archived_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
Finds matching ArchivedResourceEvents and moves them back to the ResourceEvents table.
105 106 107 108 109 110 111 112 113 114 |
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 105 def revert_assuredworkload_archived_resource_events(google_cloud_assuredworkloads_v1_revert_archived_resource_events_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/assuredworkloads:revertArchivedResourceEvents', ) command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest::Representation command.request_object = google_cloud_assuredworkloads_v1_revert_archived_resource_events_request_object command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse::Representation command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |