Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Response for ApplyWorkloadUpdate endpoint.
Instance Attribute Summary collapse
-
#applied_update ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadUpdate
A workload update is a change to the workload's compliance configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse
constructor
A new instance of GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse
Returns a new instance of GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse.
202 203 204 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_update ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadUpdate
A workload update is a change to the workload's compliance configuration.
Corresponds to the JSON property appliedUpdate
200 201 202 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 200 def applied_update @applied_update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
207 208 209 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 207 def update!(**args) @applied_update = args[:applied_update] if args.key?(:applied_update) end |