Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AssetMoveAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb

Overview

Represents move analysis results for an asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1AssetMoveAnalysis

Returns a new instance of GoogleCloudAssuredworkloadsV1AssetMoveAnalysis.



304
305
306
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_groupsArray<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisGroup>

List of eligible analyses performed for the asset. Corresponds to the JSON property analysisGroups



289
290
291
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 289

def analysis_groups
  @analysis_groups
end

#assetString

The full resource name of the asset being analyzed. Example: //compute. googleapis.com/projects/my_project_123/zones/zone1/instances/instance1 Corresponds to the JSON property asset

Returns:

  • (String)


295
296
297
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 295

def asset
  @asset
end

#asset_typeString

Type of the asset being analyzed. Possible values will be among the ones listed here. Corresponds to the JSON property assetType

Returns:

  • (String)


302
303
304
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 302

def asset_type
  @asset_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



309
310
311
312
313
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 309

def update!(**args)
  @analysis_groups = args[:analysis_groups] if args.key?(:analysis_groups)
  @asset = args[:asset] if args.key?(:asset)
  @asset_type = args[:asset_type] if args.key?(:asset_type)
end