Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ControlAssessmentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb

Overview

The details for a control assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1ControlAssessmentDetails

Returns a new instance of GoogleCloudAssuredworkloadsV1ControlAssessmentDetails.



575
576
577
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assessed_passing_control_idsArray<String>

The list of controls that were assessed and are passing. Corresponds to the JSON property assessedPassingControlIds

Returns:

  • (Array<String>)


538
539
540
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 538

def assessed_passing_control_ids
  @assessed_passing_control_ids
end

#assessed_passing_controlsFixnum

The number of controls that were assessed and are passing. Corresponds to the JSON property assessedPassingControls

Returns:

  • (Fixnum)


543
544
545
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 543

def assessed_passing_controls
  @assessed_passing_controls
end

#failing_control_idsArray<String>

The list of controls that are failing. Corresponds to the JSON property failingControlIds

Returns:

  • (Array<String>)


548
549
550
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 548

def failing_control_ids
  @failing_control_ids
end

#failing_controlsFixnum

The number of controls that are failing. Corresponds to the JSON property failingControls

Returns:

  • (Fixnum)


553
554
555
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 553

def failing_controls
  @failing_controls
end

#not_assessed_control_idsArray<String>

The list of controls that aren't assessed because they require manual review. Corresponds to the JSON property notAssessedControlIds

Returns:

  • (Array<String>)


558
559
560
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 558

def not_assessed_control_ids
  @not_assessed_control_ids
end

#not_assessed_controlsFixnum

The number of controls that aren't assessed because they require manual review. Corresponds to the JSON property notAssessedControls

Returns:

  • (Fixnum)


563
564
565
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 563

def not_assessed_controls
  @not_assessed_controls
end

#passing_control_idsArray<String>

The list of controls that are passing or not assessed. Corresponds to the JSON property passingControlIds

Returns:

  • (Array<String>)


568
569
570
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 568

def passing_control_ids
  @passing_control_ids
end

#passing_controlsFixnum

The number of controls that are passing or not assessed. Corresponds to the JSON property passingControls

Returns:

  • (Fixnum)


573
574
575
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 573

def passing_controls
  @passing_controls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



580
581
582
583
584
585
586
587
588
589
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 580

def update!(**args)
  @assessed_passing_control_ids = args[:assessed_passing_control_ids] if args.key?(:assessed_passing_control_ids)
  @assessed_passing_controls = args[:assessed_passing_controls] if args.key?(:assessed_passing_controls)
  @failing_control_ids = args[:failing_control_ids] if args.key?(:failing_control_ids)
  @failing_controls = args[:failing_controls] if args.key?(:failing_controls)
  @not_assessed_control_ids = args[:not_assessed_control_ids] if args.key?(:not_assessed_control_ids)
  @not_assessed_controls = args[:not_assessed_controls] if args.key?(:not_assessed_controls)
  @passing_control_ids = args[:passing_control_ids] if args.key?(:passing_control_ids)
  @passing_controls = args[:passing_controls] if args.key?(:passing_controls)
end