Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb

Overview

Represents a logical group of checks performed for an asset. If successful, the group contains the analysis result, otherwise it contains an error with the failure reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1MoveAnalysisGroup

Returns a new instance of GoogleCloudAssuredworkloadsV1MoveAnalysisGroup.



1122
1123
1124
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_resultGoogle::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisResult

Represents the successful move analysis results for a group. Corresponds to the JSON property analysisResult



1105
1106
1107
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1105

def analysis_result
  @analysis_result
end

#display_nameString

Name of the analysis group. Corresponds to the JSON property displayName

Returns:

  • (String)


1110
1111
1112
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1110

def display_name
  @display_name
end

#errorGoogle::Apis::AssuredworkloadsV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1120
1121
1122
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1120

def error
  @error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1127
1128
1129
1130
1131
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1127

def update!(**args)
  @analysis_result = args[:analysis_result] if args.key?(:analysis_result)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
end