Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb

Overview

Request for restricting list of available resources in Workload environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest

Returns a new instance of GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest.



616
617
618
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#restriction_typeString

Required. The type of restriction for using gcp products in the Workload environment. Corresponds to the JSON property restrictionType

Returns:

  • (String)


614
615
616
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 614

def restriction_type
  @restriction_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



621
622
623
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 621

def update!(**args)
  @restriction_type = args[:restriction_type] if args.key?(:restriction_type)
end