Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Response for reverting archived resource events.
Instance Attribute Summary collapse
-
#moved_events_count ⇒ Fixnum
The total number of events successfully moved to the original table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
constructor
A new instance of GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
Returns a new instance of GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse.
770 771 772 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 770 def initialize(**args) update!(**args) end |
Instance Attribute Details
#moved_events_count ⇒ Fixnum
The total number of events successfully moved to the original table.
Corresponds to the JSON property movedEventsCount
768 769 770 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 768 def moved_events_count @moved_events_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
775 776 777 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 775 def update!(**args) @moved_events_count = args[:moved_events_count] if args.key?(:moved_events_count) end |