Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Remediation instructions to resolve violation via gcloud cli
Instance Attribute Summary collapse
-
#additional_links ⇒ Array<String>
Additional urls for more information about steps Corresponds to the JSON property
additionalLinks. -
#gcloud_commands ⇒ Array<String>
Gcloud command to resolve violation Corresponds to the JSON property
gcloudCommands. -
#steps ⇒ Array<String>
Steps to resolve violation via gcloud cli Corresponds to the JSON property
steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud
constructor
A new instance of GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud
Returns a new instance of GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud.
954 955 956 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_links ⇒ Array<String>
Additional urls for more information about steps
Corresponds to the JSON property additionalLinks
942 943 944 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 942 def additional_links @additional_links end |
#gcloud_commands ⇒ Array<String>
Gcloud command to resolve violation
Corresponds to the JSON property gcloudCommands
947 948 949 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 947 def gcloud_commands @gcloud_commands end |
#steps ⇒ Array<String>
Steps to resolve violation via gcloud cli
Corresponds to the JSON property steps
952 953 954 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 952 def steps @steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
959 960 961 962 963 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 959 def update!(**args) @additional_links = args[:additional_links] if args.key?(:additional_links) @gcloud_commands = args[:gcloud_commands] if args.key?(:gcloud_commands) @steps = args[:steps] if args.key?(:steps) end |