Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadKmsSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb

Overview

Settings specific to the Key Management Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1WorkloadKmsSettings

Returns a new instance of GoogleCloudAssuredworkloadsV1WorkloadKmsSettings.



1430
1431
1432
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_rotation_timeString

Required. Input only. Immutable. The time at which the Key Management Service will automatically create a new version of the crypto key and mark it as the primary. Corresponds to the JSON property nextRotationTime

Returns:

  • (String)


1421
1422
1423
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1421

def next_rotation_time
  @next_rotation_time
end

#rotation_periodString

Required. Input only. Immutable. [next_rotation_time] will be advanced by this period when the Key Management Service automatically rotates a key. Must be at least 24 hours and at most 876,000 hours. Corresponds to the JSON property rotationPeriod

Returns:

  • (String)


1428
1429
1430
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1428

def rotation_period
  @rotation_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1435
1436
1437
1438
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1435

def update!(**args)
  @next_rotation_time = args[:next_rotation_time] if args.key?(:next_rotation_time)
  @rotation_period = args[:rotation_period] if args.key?(:rotation_period)
end