Class: Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
constructor
A new instance of GoogleLongrunningListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
Returns a new instance of GoogleLongrunningListOperationsResponse.
1649 1650 1651 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1634 1635 1636 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1634 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
1639 1640 1641 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1639 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
1647 1648 1649 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1647 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1654 1655 1656 1657 1658 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1654 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |