Class: Google::Apis::AssuredworkloadsV1::AssuredworkloadsService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/assuredworkloads_v1/service.rb

Overview

Assured Workloads API

Examples:

require 'google/apis/assuredworkloads_v1'

Assuredworkloads = Google::Apis::AssuredworkloadsV1 # Alias the module
service = Assuredworkloads::AssuredworkloadsService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://assuredworkloads.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeAssuredworkloadsService

Returns a new instance of AssuredworkloadsService.



47
48
49
50
51
52
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-assuredworkloads_v1',
        client_version: Google::Apis::AssuredworkloadsV1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse

Acknowledges an existing violation. By acknowledging a violation, users acknowledge the existence of a compliance violation in their workload and decide to ignore it due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted.

Parameters:

  • name (String)

    Required. The resource name of the Violation to acknowledge. Format: organizations/organization/locations/location/workloads/workload/ violations/violation

  • google_cloud_assuredworkloads_v1_acknowledge_violation_request_object (Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



625
626
627
628
629
630
631
632
633
634
635
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 625

def acknowledge_organization_location_workload_violation(name, google_cloud_assuredworkloads_v1_acknowledge_violation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:acknowledge', options)
  command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest::Representation
  command.request_object = google_cloud_assuredworkloads_v1_acknowledge_violation_request_object
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse

Analyzes a hypothetical move of a source resource to a target workload to surface compliance risks. The analysis is best effort and is not guaranteed to be exhaustive.

Parameters:

  • target (String)

    Required. The resource ID of the folder-based destination workload. This workload is where the source resource will hypothetically be moved to. Specify the workload's relative resource name, formatted as: "organizations/ ORGANIZATION_ID/locations/LOCATION_ID/workloads/WORKLOAD_ID" For example: "organizations/123/locations/us-east1/workloads/assured-workload-2"

  • asset_types (Array<String>, String) (defaults to: nil)

    Optional. List of asset types to be analyzed, including and under the source resource. If empty, all assets are analyzed. The complete list of asset types is available here.

  • page_size (Fixnum) (defaults to: nil)

    Optional. Page size. If a value is not specified, the default value of 10 is used. The maximum value is 50.

  • page_token (String) (defaults to: nil)

    Optional. The page token from the previous response. It needs to be passed in the second and following requests.

  • project (String) (defaults to: nil)

    The source type is a project. Specify the project's relative resource name, formatted as either a project number or a project ID: "projects/ PROJECT_NUMBER" or "projects/PROJECT_ID" For example: "projects/ 951040570662" when specifying a project number, or "projects/my-project-123" when specifying a project ID.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 177

def analyze_organization_location_workload_workload_move(target, asset_types: nil, page_size: nil, page_token: nil, project: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+target}:analyzeWorkloadMove', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse
  command.params['target'] = target unless target.nil?
  command.query['assetTypes'] = asset_types unless asset_types.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['project'] = project unless project.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation

This endpoint creates a new operation to apply the given update.

Parameters:

  • name (String)

    Required. The resource name of the update. Format: organizations/org_id/ locations/location_id/workloads/workload_id/updates/update_id

  • google_cloud_assuredworkloads_v1_apply_workload_update_request_object (Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



550
551
552
553
554
555
556
557
558
559
560
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 550

def apply_organization_location_workload_update(name, google_cloud_assuredworkloads_v1_apply_workload_update_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:apply', options)
  command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest::Representation
  command.request_object = google_cloud_assuredworkloads_v1_apply_workload_update_request_object
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_organization_location_workload(parent, google_cloud_assuredworkloads_v1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation

Creates Assured Workload.

Parameters:

  • parent (String)

    Required. The resource name of the new Workload's parent. Must be of the form organizations/org_id/locations/location_id``.

  • google_cloud_assuredworkloads_v1_workload_object (Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload) (defaults to: nil)
  • external_id (String) (defaults to: nil)

    Optional. A identifier associated with the workload and underlying projects which allows for the break down of billing costs for a workload. The value provided for the identifier will add a label to the workload and contained projects with the identifier as the value.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 218

def create_organization_location_workload(parent, google_cloud_assuredworkloads_v1_workload_object = nil, external_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/workloads', options)
  command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation
  command.request_object = google_cloud_assuredworkloads_v1_workload_object
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
  command.params['parent'] = parent unless parent.nil?
  command.query['externalId'] = external_id unless external_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleProtobufEmpty

Deletes the workload. Make sure that workload's direct children are already in a deleted state, otherwise the request will fail with a FAILED_PRECONDITION error. In addition to assuredworkloads.workload.delete permission, the user should also have orgpolicy.policy.set permission on the deleted folder to remove Assured Workloads OrgPolicies.

Parameters:

  • name (String)

    Required. The name field is used to identify the workload. Format: organizations/org_id/locations/location_id/workloads/workload_id

  • etag (String) (defaults to: nil)

    Optional. The etag of the workload. If this is provided, it must match the server's etag.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



259
260
261
262
263
264
265
266
267
268
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 259

def delete_organization_location_workload(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1/{+name}', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleProtobufEmpty::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleProtobufEmpty
  command.params['name'] = name unless name.nil?
  command.query['etag'] = etag unless etag.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse

This endpoint enables Assured Workloads service to offer compliance updates for the folder based assured workload. It sets up an Assured Workloads Service Agent, having permissions to read compliance controls (for example: Org Policies) applied on the workload. The caller must have resourcemanager. folders.getIamPolicy and resourcemanager.folders.setIamPolicy permissions on the assured workload folder.

Parameters:

  • name (String)

    Required. The name field is used to identify the workload. Format: organizations/org_id/locations/location_id/workloads/workload_id

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



296
297
298
299
300
301
302
303
304
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 296

def enable_organization_location_workload_compliance_updates(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:put, 'v1/{+name}:enableComplianceUpdates', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse

Enable resource violation monitoring for a workload.

Parameters:

  • name (String)

    Required. The name field is used to identify the workload. Format: organizations/org_id/locations/location_id/workloads/workload_id

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



327
328
329
330
331
332
333
334
335
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 327

def enable_organization_location_workload_resource_monitoring(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:enableResourceMonitoring', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation

Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Parameters:

  • name (String)

    The name of the operation resource.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



75
76
77
78
79
80
81
82
83
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 75

def get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningOperation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload

Gets Assured Workload associated with a CRM Node

Parameters:

  • name (String)

    Required. The resource name of the Workload to fetch. This is the workloads's relative path in the API, formatted as "organizations/organization_id/ locations/location_id/workloads/workload_id". For example, "organizations/ 123/locations/us-east1/workloads/assured-workload-1".

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



360
361
362
363
364
365
366
367
368
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 360

def get_organization_location_workload(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation

Retrieves Assured Workload Violation based on ID.

Parameters:

  • name (String)

    Required. The resource name of the Violation to fetch (ie. Violation.name). Format: organizations/organization/locations/location/workloads/workload/ violations/violation

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



659
660
661
662
663
664
665
666
667
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 659

def get_organization_location_workload_violation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse

Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.

Parameters:

  • name (String)

    The name of the operation's parent resource.

  • filter (String) (defaults to: nil)

    The standard list filter.

  • page_size (Fixnum) (defaults to: nil)

    The standard list page size.

  • page_token (String) (defaults to: nil)

    The standard list page token.

  • return_partial_success (Boolean) (defaults to: nil)

    When set to true, operations that are reachable are returned as normal, and those that are unreachable are returned in the ListOperationsResponse. unreachable field. This can only be true when reading across collections. For example, when parent is set to "projects/example/locations/-". This field is not supported by default and will result in an UNIMPLEMENTED error if set unless explicitly documented otherwise in service or product specific documentation.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 120

def list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}/operations', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleLongrunningListOperationsResponse
  command.params['name'] = name unless name.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse

This endpoint lists all updates for the given workload.

Parameters:

  • parent (String)

    Required. organizations/org_id/locations/location_id/workloads/ workload_id

  • page_size (Fixnum) (defaults to: nil)

    Page size. The default value is 20 and the max allowed value is 100.

  • page_token (String) (defaults to: nil)

    Page token returned from previous request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



587
588
589
590
591
592
593
594
595
596
597
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 587

def list_organization_location_workload_updates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/updates', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListViolationsResponse

Lists the Violations in the AssuredWorkload Environment. Callers may also choose to read across multiple Workloads as per AIP-159 by using '-' (the hyphen or dash character) as a wildcard character instead of workload-id in the parent. Format organizations/org_id/locations/ location/workloads/-

Parameters:

  • parent (String)

    Required. The Workload name. Format organizations/org_id/locations/ location/workloads/workload``.

  • filter (String) (defaults to: nil)

    Optional. A custom filter for filtering by the Violations properties.

  • interval_end_time (String) (defaults to: nil)

    The end of the time window.

  • interval_start_time (String) (defaults to: nil)

    The start of the time window.

  • page_size (Fixnum) (defaults to: nil)

    Optional. Page size.

  • page_token (String) (defaults to: nil)

    Optional. Page token returned from previous request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



704
705
706
707
708
709
710
711
712
713
714
715
716
717
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 704

def list_organization_location_workload_violations(parent, filter: nil, interval_end_time: nil, interval_start_time: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/violations', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListViolationsResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListViolationsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['interval.endTime'] = interval_end_time unless interval_end_time.nil?
  command.query['interval.startTime'] = interval_start_time unless interval_start_time.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadsResponse

Lists Assured Workloads under a CRM Node.

Parameters:

  • parent (String)

    Required. Parent Resource to list workloads from. Must be of the form organizations/org_id/locations/location``.

  • filter (String) (defaults to: nil)

    A custom filter for filtering by properties of a workload. At this time, only filtering by labels is supported.

  • page_size (Fixnum) (defaults to: nil)

    Page size.

  • page_token (String) (defaults to: nil)

    Page token returned from previous request. Page token contains context from previous request. Page token needs to be passed in the second and following requests.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 400

def list_organization_location_workloads(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/workloads', options)
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadsResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ListWorkloadsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#mutate_organization_location_workload_partner_permissions(name, google_cloud_assuredworkloads_v1_mutate_partner_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload

Update the permissions settings for an existing partner workload. For force updates don't set etag field in the Workload. Only one update operation per workload can be in progress.

Parameters:

  • name (String)

    Required. The name field is used to identify the workload. Format: organizations/org_id/locations/location_id/workloads/workload_id

  • google_cloud_assuredworkloads_v1_mutate_partner_permissions_request_object (Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



437
438
439
440
441
442
443
444
445
446
447
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 437

def mutate_organization_location_workload_partner_permissions(name, google_cloud_assuredworkloads_v1_mutate_partner_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}:mutatePartnerPermissions', options)
  command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest::Representation
  command.request_object = google_cloud_assuredworkloads_v1_mutate_partner_permissions_request_object
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_organization_location_workload(name, google_cloud_assuredworkloads_v1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload

Updates an existing workload. Currently allows updating of workload display_name and labels. For force updates don't set etag field in the Workload. Only one update operation per workload can be in progress.

Parameters:

  • name (String)

    Optional. The resource name of the workload. Format: organizations/ organization/locations/location/workloads/workload Read-only.

  • google_cloud_assuredworkloads_v1_workload_object (Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Required. The list of fields to be updated.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



475
476
477
478
479
480
481
482
483
484
485
486
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 475

def patch_organization_location_workload(name, google_cloud_assuredworkloads_v1_workload_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation
  command.request_object = google_cloud_assuredworkloads_v1_workload_object
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse

Restrict the list of resources allowed in the Workload environment. The current list of allowed products can be found at https://cloud.google.com/ assured-workloads/docs/supported-products In addition to assuredworkloads. workload.update permission, the user should also have orgpolicy.policy.set permission on the folder resource to use this functionality.

Parameters:

  • name (String)

    Required. The resource name of the Workload. This is the workloads's relative path in the API, formatted as "organizations/organization_id/locations/ location_id/workloads/workload_id". For example, "organizations/123/ locations/us-east1/workloads/assured-workload-1".

  • google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object (Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



516
517
518
519
520
521
522
523
524
525
526
# File 'lib/google/apis/assuredworkloads_v1/service.rb', line 516

def restrict_organization_location_workload_allowed_resources(name, google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:restrictAllowedResources', options)
  command.request_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest::Representation
  command.request_object = google_cloud_assuredworkloads_v1_restrict_allowed_resources_request_object
  command.response_representation = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse::Representation
  command.response_class = Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end