Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1CloudControlReport
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1CloudControlReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
The cloud control report.
Instance Attribute Summary collapse
-
#categories ⇒ Array<String>
The list of categories for the cloud control.
-
#cloud_control ⇒ String
The name of the cloud control.
-
#cloud_control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1CloudControlAssessmentDetails
The cloud control assessment details for non-manual cloud controls.
-
#cloud_control_deployment ⇒ String
The name of the cloud control deployment.
-
#cloud_control_type ⇒ String
The type of the cloud control.
-
#description ⇒ String
The description of the cloud control.
-
#display_name ⇒ String
The display name of the cloud control.
-
#enforcement_mode ⇒ String
The enforcement mode of the cloud control.
-
#finding_category ⇒ String
The category of the finding.
-
#finding_severity ⇒ String
The severity of the finding.
-
#framework_major_revision_ids ⇒ Array<Fixnum>
The major revision IDs of the frameworks that the cloud control belongs to.
-
#major_revision_id ⇒ Fixnum
The major revision ID of the cloud control.
-
#manual_cloud_control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ManualCloudControlAssessmentDetails
The details for a manual cloud control assessment.
-
#minor_revision_id ⇒ Fixnum
The minor revision ID of the cloud control.
-
#rules ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Rule>
The list of rules that correspond to the cloud control.
-
#similar_controls ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1SimilarControls>
The list of similar controls.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1CloudControlReport
constructor
A new instance of GoogleCloudAssuredworkloadsV1CloudControlReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1CloudControlReport
Returns a new instance of GoogleCloudAssuredworkloadsV1CloudControlReport.
506 507 508 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categories ⇒ Array<String>
The list of categories for the cloud control.
Corresponds to the JSON property categories
429 430 431 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 429 def categories @categories end |
#cloud_control ⇒ String
The name of the cloud control.
Corresponds to the JSON property cloudControl
434 435 436 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 434 def cloud_control @cloud_control end |
#cloud_control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1CloudControlAssessmentDetails
The cloud control assessment details for non-manual cloud controls.
Corresponds to the JSON property cloudControlAssessmentDetails
439 440 441 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 439 def cloud_control_assessment_details @cloud_control_assessment_details end |
#cloud_control_deployment ⇒ String
The name of the cloud control deployment.
Corresponds to the JSON property cloudControlDeployment
444 445 446 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 444 def cloud_control_deployment @cloud_control_deployment end |
#cloud_control_type ⇒ String
The type of the cloud control.
Corresponds to the JSON property cloudControlType
449 450 451 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 449 def cloud_control_type @cloud_control_type end |
#description ⇒ String
The description of the cloud control.
Corresponds to the JSON property description
454 455 456 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 454 def description @description end |
#display_name ⇒ String
The display name of the cloud control.
Corresponds to the JSON property displayName
459 460 461 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 459 def display_name @display_name end |
#enforcement_mode ⇒ String
The enforcement mode of the cloud control.
Corresponds to the JSON property enforcementMode
464 465 466 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 464 def enforcement_mode @enforcement_mode end |
#finding_category ⇒ String
The category of the finding.
Corresponds to the JSON property findingCategory
469 470 471 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 469 def finding_category @finding_category end |
#finding_severity ⇒ String
The severity of the finding.
Corresponds to the JSON property findingSeverity
474 475 476 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 474 def finding_severity @finding_severity end |
#framework_major_revision_ids ⇒ Array<Fixnum>
The major revision IDs of the frameworks that the cloud control belongs to.
Corresponds to the JSON property frameworkMajorRevisionIds
479 480 481 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 479 def framework_major_revision_ids @framework_major_revision_ids end |
#major_revision_id ⇒ Fixnum
The major revision ID of the cloud control.
Corresponds to the JSON property majorRevisionId
484 485 486 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 484 def major_revision_id @major_revision_id end |
#manual_cloud_control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ManualCloudControlAssessmentDetails
The details for a manual cloud control assessment.
Corresponds to the JSON property manualCloudControlAssessmentDetails
489 490 491 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 489 def manual_cloud_control_assessment_details @manual_cloud_control_assessment_details end |
#minor_revision_id ⇒ Fixnum
The minor revision ID of the cloud control.
Corresponds to the JSON property minorRevisionId
494 495 496 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 494 def minor_revision_id @minor_revision_id end |
#rules ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Rule>
The list of rules that correspond to the cloud control.
Corresponds to the JSON property rules
499 500 501 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 499 def rules @rules end |
#similar_controls ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1SimilarControls>
The list of similar controls.
Corresponds to the JSON property similarControls
504 505 506 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 504 def similar_controls @similar_controls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 511 def update!(**args) @categories = args[:categories] if args.key?(:categories) @cloud_control = args[:cloud_control] if args.key?(:cloud_control) @cloud_control_assessment_details = args[:cloud_control_assessment_details] if args.key?(:cloud_control_assessment_details) @cloud_control_deployment = args[:cloud_control_deployment] if args.key?(:cloud_control_deployment) @cloud_control_type = args[:cloud_control_type] if args.key?(:cloud_control_type) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode) @finding_category = args[:finding_category] if args.key?(:finding_category) @finding_severity = args[:finding_severity] if args.key?(:finding_severity) @framework_major_revision_ids = args[:framework_major_revision_ids] if args.key?(:framework_major_revision_ids) @major_revision_id = args[:major_revision_id] if args.key?(:major_revision_id) @manual_cloud_control_assessment_details = args[:manual_cloud_control_assessment_details] if args.key?(:manual_cloud_control_assessment_details) @minor_revision_id = args[:minor_revision_id] if args.key?(:minor_revision_id) @rules = args[:rules] if args.key?(:rules) @similar_controls = args[:similar_controls] if args.key?(:similar_controls) end |