Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1DbControlComplianceSummary
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1DbControlComplianceSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
The details for control compliance.
Instance Attribute Summary collapse
-
#cloud_control_reports ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1CloudControlReport>
The list of cloud control reports.
-
#compliance_frameworks ⇒ Array<String>
The list of compliance frameworks that the control belongs to.
-
#control ⇒ String
The name of the control.
-
#control_responsibility_type ⇒ String
The responsibility type for the control.
-
#description ⇒ String
The description of the control.
-
#display_name ⇒ String
The display name of the control.
-
#is_fake_control ⇒ Boolean
(also: #is_fake_control?)
Whether the control is a fake control.
-
#name ⇒ String
Identifier.
-
#overall_evaluation_state ⇒ String
Output only.
-
#similar_controls ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1SimilarControls>
The list of similar controls.
-
#total_findings_count ⇒ Fixnum
The total number of findings for the control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1DbControlComplianceSummary
constructor
A new instance of GoogleCloudAssuredworkloadsV1DbControlComplianceSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1DbControlComplianceSummary
Returns a new instance of GoogleCloudAssuredworkloadsV1DbControlComplianceSummary.
691 692 693 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_control_reports ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1CloudControlReport>
The list of cloud control reports.
Corresponds to the JSON property cloudControlReports
637 638 639 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 637 def cloud_control_reports @cloud_control_reports end |
#compliance_frameworks ⇒ Array<String>
The list of compliance frameworks that the control belongs to.
Corresponds to the JSON property complianceFrameworks
642 643 644 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 642 def compliance_frameworks @compliance_frameworks end |
#control ⇒ String
The name of the control.
Corresponds to the JSON property control
647 648 649 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 647 def control @control end |
#control_responsibility_type ⇒ String
The responsibility type for the control.
Corresponds to the JSON property controlResponsibilityType
652 653 654 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 652 def control_responsibility_type @control_responsibility_type end |
#description ⇒ String
The description of the control.
Corresponds to the JSON property description
657 658 659 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 657 def description @description end |
#display_name ⇒ String
The display name of the control.
Corresponds to the JSON property displayName
662 663 664 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 662 def display_name @display_name end |
#is_fake_control ⇒ Boolean Also known as: is_fake_control?
Whether the control is a fake control. Fake controls are created and mapped to
cloud controls that don't belong to a control group.
Corresponds to the JSON property isFakeControl
668 669 670 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 668 def is_fake_control @is_fake_control end |
#name ⇒ String
Identifier. The name of the control compliance summary.
Corresponds to the JSON property name
674 675 676 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 674 def name @name end |
#overall_evaluation_state ⇒ String
Output only. The overall evaluation status of the control.
Corresponds to the JSON property overallEvaluationState
679 680 681 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 679 def overall_evaluation_state @overall_evaluation_state end |
#similar_controls ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1SimilarControls>
The list of similar controls.
Corresponds to the JSON property similarControls
684 685 686 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 684 def similar_controls @similar_controls end |
#total_findings_count ⇒ Fixnum
The total number of findings for the control.
Corresponds to the JSON property totalFindingsCount
689 690 691 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 689 def total_findings_count @total_findings_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
696 697 698 699 700 701 702 703 704 705 706 707 708 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 696 def update!(**args) @cloud_control_reports = args[:cloud_control_reports] if args.key?(:cloud_control_reports) @compliance_frameworks = args[:compliance_frameworks] if args.key?(:compliance_frameworks) @control = args[:control] if args.key?(:control) @control_responsibility_type = args[:control_responsibility_type] if args.key?(:control_responsibility_type) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @is_fake_control = args[:is_fake_control] if args.key?(:is_fake_control) @name = args[:name] if args.key?(:name) @overall_evaluation_state = args[:overall_evaluation_state] if args.key?(:overall_evaluation_state) @similar_controls = args[:similar_controls] if args.key?(:similar_controls) @total_findings_count = args[:total_findings_count] if args.key?(:total_findings_count) end |