Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1DbFindingSummary
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1DbFindingSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
The details for a finding.
Instance Attribute Summary collapse
-
#finding_category ⇒ String
Output only.
-
#finding_class ⇒ String
Output only.
-
#finding_count ⇒ Fixnum
Output only.
-
#name ⇒ String
Identifier.
-
#organization_policy_finding_count ⇒ Fixnum
Output only.
-
#related_frameworks ⇒ Array<String>
Optional.
-
#resource_finding_count ⇒ Fixnum
Output only.
-
#severity ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1DbFindingSummary
constructor
A new instance of GoogleCloudAssuredworkloadsV1DbFindingSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1DbFindingSummary
Returns a new instance of GoogleCloudAssuredworkloadsV1DbFindingSummary.
707 708 709 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finding_category ⇒ String
Output only. The category of the finding.
Corresponds to the JSON property findingCategory
665 666 667 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 665 def finding_category @finding_category end |
#finding_class ⇒ String
Output only. The class of the finding.
Corresponds to the JSON property findingClass
670 671 672 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 670 def finding_class @finding_class end |
#finding_count ⇒ Fixnum
Output only. The count of the finding.
Corresponds to the JSON property findingCount
675 676 677 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 675 def finding_count @finding_count end |
#name ⇒ String
Identifier. The name of the finding summary.
Corresponds to the JSON property name
680 681 682 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 680 def name @name end |
#organization_policy_finding_count ⇒ Fixnum
Output only. Number of active organization policy findings for this category.
Corresponds to the JSON property organizationPolicyFindingCount
685 686 687 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 685 def organization_policy_finding_count @organization_policy_finding_count end |
#related_frameworks ⇒ Array<String>
Optional. The list of compliance frameworks that the finding belongs to.
Corresponds to the JSON property relatedFrameworks
690 691 692 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 690 def @related_frameworks end |
#resource_finding_count ⇒ Fixnum
Output only. Number of active resource findings for this category.
Corresponds to the JSON property resourceFindingCount
695 696 697 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 695 def resource_finding_count @resource_finding_count end |
#severity ⇒ String
Output only. The severity of the finding.
Corresponds to the JSON property severity
700 701 702 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 700 def severity @severity end |
#update_time ⇒ String
Output only. The last updated time of the finding.
Corresponds to the JSON property updateTime
705 706 707 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 705 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
712 713 714 715 716 717 718 719 720 721 722 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 712 def update!(**args) @finding_category = args[:finding_category] if args.key?(:finding_category) @finding_class = args[:finding_class] if args.key?(:finding_class) @finding_count = args[:finding_count] if args.key?(:finding_count) @name = args[:name] if args.key?(:name) @organization_policy_finding_count = args[:organization_policy_finding_count] if args.key?(:organization_policy_finding_count) @related_frameworks = args[:related_frameworks] if args.key?(:related_frameworks) @resource_finding_count = args[:resource_finding_count] if args.key?(:resource_finding_count) @severity = args[:severity] if args.key?(:severity) @update_time = args[:update_time] if args.key?(:update_time) end |