Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1DbFrameworkComplianceSummary
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1DbFrameworkComplianceSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
The details for a framework compliance summary.
Instance Attribute Summary collapse
-
#control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ControlAssessmentDetails
The details for a control assessment.
-
#controls_passing_trend ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Trend
The trend of a compliance metric.
-
#finding_count ⇒ Fixnum
Output only.
-
#framework ⇒ String
The name of the framework.
-
#framework_categories ⇒ Array<String>
The list of framework categories supported by the framework.
-
#framework_display_name ⇒ String
Optional.
-
#framework_type ⇒ String
The type of framework.
-
#major_revision_id ⇒ Fixnum
The major revision ID of the framework.
-
#minor_revision_id ⇒ Fixnum
The minor revision ID of the framework.
-
#name ⇒ String
Identifier.
-
#supported_cloud_providers ⇒ Array<String>
The list of cloud providers supported by the framework.
-
#target_resource_details ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1TargetResourceDetails>
The target resource details for the framework.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1DbFrameworkComplianceSummary
constructor
A new instance of GoogleCloudAssuredworkloadsV1DbFrameworkComplianceSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1DbFrameworkComplianceSummary
Returns a new instance of GoogleCloudAssuredworkloadsV1DbFrameworkComplianceSummary.
830 831 832 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ControlAssessmentDetails
The details for a control assessment.
Corresponds to the JSON property controlAssessmentDetails
773 774 775 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 773 def control_assessment_details @control_assessment_details end |
#controls_passing_trend ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Trend
The trend of a compliance metric.
Corresponds to the JSON property controlsPassingTrend
778 779 780 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 778 def controls_passing_trend @controls_passing_trend end |
#finding_count ⇒ Fixnum
Output only. The count of the findings generated against the framework.
Corresponds to the JSON property findingCount
783 784 785 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 783 def finding_count @finding_count end |
#framework ⇒ String
The name of the framework.
Corresponds to the JSON property framework
788 789 790 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 788 def framework @framework end |
#framework_categories ⇒ Array<String>
The list of framework categories supported by the framework.
Corresponds to the JSON property frameworkCategories
793 794 795 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 793 def framework_categories @framework_categories end |
#framework_display_name ⇒ String
Optional. The display name for the framework.
Corresponds to the JSON property frameworkDisplayName
798 799 800 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 798 def framework_display_name @framework_display_name end |
#framework_type ⇒ String
The type of framework.
Corresponds to the JSON property frameworkType
803 804 805 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 803 def framework_type @framework_type end |
#major_revision_id ⇒ Fixnum
The major revision ID of the framework.
Corresponds to the JSON property majorRevisionId
808 809 810 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 808 def major_revision_id @major_revision_id end |
#minor_revision_id ⇒ Fixnum
The minor revision ID of the framework.
Corresponds to the JSON property minorRevisionId
813 814 815 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 813 def minor_revision_id @minor_revision_id end |
#name ⇒ String
Identifier. The name of the framework compliance summary.
Corresponds to the JSON property name
818 819 820 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 818 def name @name end |
#supported_cloud_providers ⇒ Array<String>
The list of cloud providers supported by the framework.
Corresponds to the JSON property supportedCloudProviders
823 824 825 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 823 def supported_cloud_providers @supported_cloud_providers end |
#target_resource_details ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1TargetResourceDetails>
The target resource details for the framework.
Corresponds to the JSON property targetResourceDetails
828 829 830 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 828 def target_resource_details @target_resource_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 835 def update!(**args) @control_assessment_details = args[:control_assessment_details] if args.key?(:control_assessment_details) @controls_passing_trend = args[:controls_passing_trend] if args.key?(:controls_passing_trend) @finding_count = args[:finding_count] if args.key?(:finding_count) @framework = args[:framework] if args.key?(:framework) @framework_categories = args[:framework_categories] if args.key?(:framework_categories) @framework_display_name = args[:framework_display_name] if args.key?(:framework_display_name) @framework_type = args[:framework_type] if args.key?(:framework_type) @major_revision_id = args[:major_revision_id] if args.key?(:major_revision_id) @minor_revision_id = args[:minor_revision_id] if args.key?(:minor_revision_id) @name = args[:name] if args.key?(:name) @supported_cloud_providers = args[:supported_cloud_providers] if args.key?(:supported_cloud_providers) @target_resource_details = args[:target_resource_details] if args.key?(:target_resource_details) end |