Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
The response message for FetchDbFrameworkComplianceReport.
Instance Attribute Summary collapse
-
#control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ControlAssessmentDetails
The details for a control assessment.
-
#framework ⇒ String
The name of the framework.
-
#framework_categories ⇒ Array<String>
The list of framework categories supported.
-
#framework_description ⇒ String
The description of the framework.
-
#framework_display_name ⇒ String
Optional.
-
#framework_type ⇒ String
The type of the framework.
-
#major_revision_id ⇒ Fixnum
The latest major revision ID of the framework.
-
#minor_revision_id ⇒ Fixnum
The latest minor revision ID of the latest major revision of the framework.
-
#name ⇒ String
The name of the framework compliance report.
-
#supported_cloud_providers ⇒ Array<String>
The list of cloud providers that are supported by the framework.
-
#target_resource_details ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1TargetResourceDetails>
The target resource details of the framework.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse
constructor
A new instance of GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse
Returns a new instance of GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse.
941 942 943 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#control_assessment_details ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ControlAssessmentDetails
The details for a control assessment.
Corresponds to the JSON property controlAssessmentDetails
884 885 886 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 884 def control_assessment_details @control_assessment_details end |
#framework ⇒ String
The name of the framework.
Corresponds to the JSON property framework
889 890 891 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 889 def framework @framework end |
#framework_categories ⇒ Array<String>
The list of framework categories supported.
Corresponds to the JSON property frameworkCategories
894 895 896 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 894 def framework_categories @framework_categories end |
#framework_description ⇒ String
The description of the framework.
Corresponds to the JSON property frameworkDescription
899 900 901 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 899 def framework_description @framework_description end |
#framework_display_name ⇒ String
Optional. The display name for the framework.
Corresponds to the JSON property frameworkDisplayName
904 905 906 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 904 def framework_display_name @framework_display_name end |
#framework_type ⇒ String
The type of the framework.
Corresponds to the JSON property frameworkType
909 910 911 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 909 def framework_type @framework_type end |
#major_revision_id ⇒ Fixnum
The latest major revision ID of the framework.
Corresponds to the JSON property majorRevisionId
914 915 916 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 914 def major_revision_id @major_revision_id end |
#minor_revision_id ⇒ Fixnum
The latest minor revision ID of the latest major revision of the framework.
Corresponds to the JSON property minorRevisionId
919 920 921 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 919 def minor_revision_id @minor_revision_id end |
#name ⇒ String
The name of the framework compliance report.
Corresponds to the JSON property name
924 925 926 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 924 def name @name end |
#supported_cloud_providers ⇒ Array<String>
The list of cloud providers that are supported by the framework.
Corresponds to the JSON property supportedCloudProviders
929 930 931 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 929 def supported_cloud_providers @supported_cloud_providers end |
#target_resource_details ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1TargetResourceDetails>
The target resource details of the framework.
Corresponds to the JSON property targetResourceDetails
934 935 936 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 934 def target_resource_details @target_resource_details end |
#update_time ⇒ String
Output only. The last updated time of the report.
Corresponds to the JSON property updateTime
939 940 941 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 939 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
946 947 948 949 950 951 952 953 954 955 956 957 958 959 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 946 def update!(**args) @control_assessment_details = args[:control_assessment_details] if args.key?(:control_assessment_details) @framework = args[:framework] if args.key?(:framework) @framework_categories = args[:framework_categories] if args.key?(:framework_categories) @framework_description = args[:framework_description] if args.key?(:framework_description) @framework_display_name = args[:framework_display_name] if args.key?(:framework_display_name) @framework_type = args[:framework_type] if args.key?(:framework_type) @major_revision_id = args[:major_revision_id] if args.key?(:major_revision_id) @minor_revision_id = args[:minor_revision_id] if args.key?(:minor_revision_id) @name = args[:name] if args.key?(:name) @supported_cloud_providers = args[:supported_cloud_providers] if args.key?(:supported_cloud_providers) @target_resource_details = args[:target_resource_details] if args.key?(:target_resource_details) @update_time = args[:update_time] if args.key?(:update_time) end |