Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Represents a logical group of checks performed for an asset. If successful, the group contains the analysis result, otherwise it contains an error with the failure reason.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisResult
Represents the successful move analysis results for a group.
-
#display_name ⇒ String
Name of the analysis group.
-
#error ⇒ Google::Apis::AssuredworkloadsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
constructor
A new instance of GoogleCloudAssuredworkloadsV1MoveAnalysisGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
Returns a new instance of GoogleCloudAssuredworkloadsV1MoveAnalysisGroup.
1163 1164 1165 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisResult
Represents the successful move analysis results for a group.
Corresponds to the JSON property analysisResult
1146 1147 1148 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1146 def analysis_result @analysis_result end |
#display_name ⇒ String
Name of the analysis group.
Corresponds to the JSON property displayName
1151 1152 1153 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1151 def display_name @display_name end |
#error ⇒ Google::Apis::AssuredworkloadsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1161 1162 1163 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1161 def error @error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1168 1169 1170 1171 1172 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1168 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) end |