Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Represents a logical group of checks performed for an asset. If successful, the group contains the analysis result, otherwise it contains an error with the failure reason.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisResult
Represents the successful move analysis results for a group.
-
#display_name ⇒ String
Name of the analysis group.
-
#error ⇒ Google::Apis::AssuredworkloadsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
constructor
A new instance of GoogleCloudAssuredworkloadsV1MoveAnalysisGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
Returns a new instance of GoogleCloudAssuredworkloadsV1MoveAnalysisGroup.
484 485 486 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1MoveAnalysisResult
Represents the successful move analysis results for a group.
Corresponds to the JSON property analysisResult
467 468 469 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 467 def analysis_result @analysis_result end |
#display_name ⇒ String
Name of the analysis group.
Corresponds to the JSON property displayName
472 473 474 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 472 def display_name @display_name end |
#error ⇒ Google::Apis::AssuredworkloadsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
482 483 484 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 482 def error @error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
489 490 491 492 493 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 489 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) end |