Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicyUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb

Overview

Represents an update for an org policy control applied on an Assured Workload resource. The inherited org policy is not considered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1OrgPolicyUpdate

Returns a new instance of GoogleCloudAssuredworkloadsV1OrgPolicyUpdate.



1391
1392
1393
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_policyGoogle::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicy

This assured workload service object is used to represent the org policy attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy object but with functionality that is limited to what is supported by Assured Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc). Corresponds to the JSON property appliedPolicy



1381
1382
1383
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1381

def applied_policy
  @applied_policy
end

#suggested_policyGoogle::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicy

This assured workload service object is used to represent the org policy attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy object but with functionality that is limited to what is supported by Assured Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc). Corresponds to the JSON property suggestedPolicy



1389
1390
1391
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1389

def suggested_policy
  @suggested_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1396
1397
1398
1399
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1396

def update!(**args)
  @applied_policy = args[:applied_policy] if args.key?(:applied_policy)
  @suggested_policy = args[:suggested_policy] if args.key?(:suggested_policy)
end