Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Represents an update for an org policy control applied on an Assured Workload resource. The inherited org policy is not considered.
Instance Attribute Summary collapse
-
#applied_policy ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicy
This assured workload service object is used to represent the org policy attached to a resource.
-
#suggested_policy ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicy
This assured workload service object is used to represent the org policy attached to a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
constructor
A new instance of GoogleCloudAssuredworkloadsV1OrgPolicyUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
Returns a new instance of GoogleCloudAssuredworkloadsV1OrgPolicyUpdate.
712 713 714 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_policy ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicy
This assured workload service object is used to represent the org policy
attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy
object but with functionality that is limited to what is supported by Assured
Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc).
Corresponds to the JSON property appliedPolicy
702 703 704 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 702 def applied_policy @applied_policy end |
#suggested_policy ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicy
This assured workload service object is used to represent the org policy
attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy
object but with functionality that is limited to what is supported by Assured
Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc).
Corresponds to the JSON property suggestedPolicy
710 711 712 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 710 def suggested_policy @suggested_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
717 718 719 720 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 717 def update!(**args) @applied_policy = args[:applied_policy] if args.key?(:applied_policy) @suggested_policy = args[:suggested_policy] if args.key?(:suggested_policy) end |