Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Request for reverting archived resource events.
Instance Attribute Summary collapse
-
#archive_end_time ⇒ String
Required.
-
#archive_start_time ⇒ String
Required.
-
#batch_size ⇒ Fixnum
Required.
-
#max_events_move ⇒ Fixnum
Required.
-
#organization_id ⇒ Fixnum
Required.
-
#region ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest
constructor
A new instance of GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest
Returns a new instance of GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest.
746 747 748 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_end_time ⇒ String
Required. Only events within this time range will be reverted. This helps
prevent reverting everything when something goes wrong.
Corresponds to the JSON property archiveEndTime
717 718 719 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 717 def archive_end_time @archive_end_time end |
#archive_start_time ⇒ String
Required. Only events within this time range will be reverted. This helps
prevent reverting everything when something goes wrong.
Corresponds to the JSON property archiveStartTime
723 724 725 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 723 def archive_start_time @archive_start_time end |
#batch_size ⇒ Fixnum
Required. The number of events to process in a single transaction batch.
Corresponds to the JSON property batchSize
728 729 730 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 728 def batch_size @batch_size end |
#max_events_move ⇒ Fixnum
Required. The maximum total number of events to move in this request.
Corresponds to the JSON property maxEventsMove
733 734 735 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 733 def max_events_move @max_events_move end |
#organization_id ⇒ Fixnum
Required. The organization ID for which to revert events.
Corresponds to the JSON property organizationId
738 739 740 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 738 def organization_id @organization_id end |
#region ⇒ String
Required. The region of the workload(s) whose events should be reverted. This
is used to filter workloads based on AssurantWorkloadData.region.
Corresponds to the JSON property region
744 745 746 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 744 def region @region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
751 752 753 754 755 756 757 758 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 751 def update!(**args) @archive_end_time = args[:archive_end_time] if args.key?(:archive_end_time) @archive_start_time = args[:archive_start_time] if args.key?(:archive_start_time) @batch_size = args[:batch_size] if args.key?(:batch_size) @max_events_move = args[:max_events_move] if args.key?(:max_events_move) @organization_id = args[:organization_id] if args.key?(:organization_id) @region = args[:region] if args.key?(:region) end |