Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1UpdateDetails
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1UpdateDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
The details of the update.
Instance Attribute Summary collapse
-
#org_policy_update ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
Represents an update for an org policy control applied on an Assured Workload resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1UpdateDetails
constructor
A new instance of GoogleCloudAssuredworkloadsV1UpdateDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1UpdateDetails
Returns a new instance of GoogleCloudAssuredworkloadsV1UpdateDetails.
837 838 839 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#org_policy_update ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
Represents an update for an org policy control applied on an Assured Workload
resource. The inherited org policy is not considered.
Corresponds to the JSON property orgPolicyUpdate
835 836 837 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 835 def org_policy_update @org_policy_update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
842 843 844 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 842 def update!(**args) @org_policy_update = args[:org_policy_update] if args.key?(:org_policy_update) end |