Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Violation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
Workload monitoring Violation.
Instance Attribute Summary collapse
-
#acknowledged ⇒ Boolean
(also: #acknowledged?)
A boolean that indicates if the violation is acknowledged Corresponds to the JSON property
acknowledged. -
#acknowledgement_time ⇒ String
Optional.
-
#associated_org_policy_violation_id ⇒ String
Optional.
-
#audit_log_link ⇒ String
Output only.
-
#begin_time ⇒ String
Output only.
-
#category ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#exception_audit_log_link ⇒ String
Output only.
-
#exception_contexts ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ViolationExceptionContext>
Output only.
-
#name ⇒ String
Output only.
-
#non_compliant_org_policy ⇒ String
Output only.
-
#org_policy_constraint ⇒ String
Output only.
-
#parent_project_number ⇒ String
Optional.
-
#remediation ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ViolationRemediation
Represents remediation guidance to resolve compliance violation for AssuredWorkload Corresponds to the JSON property
remediation. -
#resolve_time ⇒ String
Output only.
-
#resource_name ⇒ String
Optional.
-
#resource_type ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#violation_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1Violation
constructor
A new instance of GoogleCloudAssuredworkloadsV1Violation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1Violation
Returns a new instance of GoogleCloudAssuredworkloadsV1Violation.
1772 1773 1774 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acknowledged ⇒ Boolean Also known as: acknowledged?
A boolean that indicates if the violation is acknowledged
Corresponds to the JSON property acknowledged
1652 1653 1654 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1652 def acknowledged @acknowledged end |
#acknowledgement_time ⇒ String
Optional. Timestamp when this violation was acknowledged first. Check
exception_contexts to find the last time the violation was acknowledged when
there are more than one violations. This field will be absent when
acknowledged field is marked as false.
Corresponds to the JSON property acknowledgementTime
1661 1662 1663 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1661 def acknowledgement_time @acknowledgement_time end |
#associated_org_policy_violation_id ⇒ String
Optional. Output only. Violation Id of the org-policy violation due to which
the resource violation is caused. Empty for org-policy violations.
Corresponds to the JSON property associatedOrgPolicyViolationId
1667 1668 1669 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1667 def associated_org_policy_violation_id @associated_org_policy_violation_id end |
#audit_log_link ⇒ String
Output only. Immutable. Audit Log Link for violated resource Format: https://
console.cloud.google.com/logs/query;query=logNameprotoPayload.resourceName
timeRangefolder
Corresponds to the JSON property auditLogLink
1674 1675 1676 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1674 def audit_log_link @audit_log_link end |
#begin_time ⇒ String
Output only. Time of the event which triggered the Violation.
Corresponds to the JSON property beginTime
1679 1680 1681 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1679 def begin_time @begin_time end |
#category ⇒ String
Output only. Category under which this violation is mapped. e.g. Location,
Service Usage, Access, Encryption, etc.
Corresponds to the JSON property category
1685 1686 1687 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1685 def category @category end |
#description ⇒ String
Output only. Description for the Violation. e.g. OrgPolicy gcp.
resourceLocations has non compliant value.
Corresponds to the JSON property description
1691 1692 1693 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1691 def description @description end |
#exception_audit_log_link ⇒ String
Output only. Immutable. Audit Log link to find business justification provided
for violation exception. Format: https://console.cloud.google.com/logs/query;
query=logNameprotoPayload.resourceNameprotoPayload.methodNametimeRange
organization
Corresponds to the JSON property exceptionAuditLogLink
1699 1700 1701 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1699 def exception_audit_log_link @exception_audit_log_link end |
#exception_contexts ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ViolationExceptionContext>
Output only. List of all the exception detail added for the violation.
Corresponds to the JSON property exceptionContexts
1704 1705 1706 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1704 def exception_contexts @exception_contexts end |
#name ⇒ String
Output only. Immutable. Name of the Violation. Format: organizations/
organization/locations/location/workloads/workload_id/violations/
violations_id
Corresponds to the JSON property name
1711 1712 1713 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1711 def name @name end |
#non_compliant_org_policy ⇒ String
Output only. Immutable. Name of the OrgPolicy which was modified with non-
compliant change and resulted this violation. Format: projects/project_number
/policies/constraint_name folders/folder_id/policies/constraint_name
organizations/organization_id/policies/constraint_name
Corresponds to the JSON property nonCompliantOrgPolicy
1719 1720 1721 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1719 def non_compliant_org_policy @non_compliant_org_policy end |
#org_policy_constraint ⇒ String
Output only. Immutable. The org-policy-constraint that was incorrectly changed,
which resulted in this violation.
Corresponds to the JSON property orgPolicyConstraint
1725 1726 1727 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1725 def org_policy_constraint @org_policy_constraint end |
#parent_project_number ⇒ String
Optional. Output only. Parent project number where resource is present. Empty
for org-policy violations.
Corresponds to the JSON property parentProjectNumber
1731 1732 1733 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1731 def parent_project_number @parent_project_number end |
#remediation ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1ViolationRemediation
Represents remediation guidance to resolve compliance violation for
AssuredWorkload
Corresponds to the JSON property remediation
1737 1738 1739 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1737 def remediation @remediation end |
#resolve_time ⇒ String
Output only. Time of the event which fixed the Violation. If the violation is
ACTIVE this will be empty.
Corresponds to the JSON property resolveTime
1743 1744 1745 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1743 def resolve_time @resolve_time end |
#resource_name ⇒ String
Optional. Output only. Name of the resource like //storage.googleapis.com/
myprojectxyz-testbucket. Empty for org-policy violations.
Corresponds to the JSON property resourceName
1749 1750 1751 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1749 def resource_name @resource_name end |
#resource_type ⇒ String
Optional. Output only. Type of the resource like compute.googleapis.com/Disk,
etc. Empty for org-policy violations.
Corresponds to the JSON property resourceType
1755 1756 1757 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1755 def resource_type @resource_type end |
#state ⇒ String
Output only. State of the violation
Corresponds to the JSON property state
1760 1761 1762 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1760 def state @state end |
#update_time ⇒ String
Output only. The last time when the Violation record was updated.
Corresponds to the JSON property updateTime
1765 1766 1767 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1765 def update_time @update_time end |
#violation_type ⇒ String
Output only. Type of the violation
Corresponds to the JSON property violationType
1770 1771 1772 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1770 def violation_type @violation_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1777 def update!(**args) @acknowledged = args[:acknowledged] if args.key?(:acknowledged) @acknowledgement_time = args[:acknowledgement_time] if args.key?(:acknowledgement_time) @associated_org_policy_violation_id = args[:associated_org_policy_violation_id] if args.key?(:associated_org_policy_violation_id) @audit_log_link = args[:audit_log_link] if args.key?(:audit_log_link) @begin_time = args[:begin_time] if args.key?(:begin_time) @category = args[:category] if args.key?(:category) @description = args[:description] if args.key?(:description) @exception_audit_log_link = args[:exception_audit_log_link] if args.key?(:exception_audit_log_link) @exception_contexts = args[:exception_contexts] if args.key?(:exception_contexts) @name = args[:name] if args.key?(:name) @non_compliant_org_policy = args[:non_compliant_org_policy] if args.key?(:non_compliant_org_policy) @org_policy_constraint = args[:org_policy_constraint] if args.key?(:org_policy_constraint) @parent_project_number = args[:parent_project_number] if args.key?(:parent_project_number) @remediation = args[:remediation] if args.key?(:remediation) @resolve_time = args[:resolve_time] if args.key?(:resolve_time) @resource_name = args[:resource_name] if args.key?(:resource_name) @resource_type = args[:resource_type] if args.key?(:resource_type) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @violation_type = args[:violation_type] if args.key?(:violation_type) end |