Class: Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
- Inherits:
-
Object
- Object
- Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1Workload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/assuredworkloads_v1/classes.rb,
lib/google/apis/assuredworkloads_v1/representations.rb,
lib/google/apis/assuredworkloads_v1/representations.rb
Overview
A Workload object for managing highly regulated workloads of cloud customers.
Instance Attribute Summary collapse
-
#billing_account ⇒ String
Optional.
-
#compliance_regime ⇒ String
Required.
-
#compliance_status ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus
Represents the Compliance Status of this workload Corresponds to the JSON property
complianceStatus. -
#compliant_but_disallowed_services ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#ekm_provisioning_response ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse
External key management systems(EKM) Provisioning response Corresponds to the JSON property
ekmProvisioningResponse. -
#enable_sovereign_controls ⇒ Boolean
(also: #enable_sovereign_controls?)
Optional.
-
#etag ⇒ String
Optional.
-
#kaj_enrollment_state ⇒ String
Output only.
-
#kms_settings ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadKmsSettings
Settings specific to the Key Management Service.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Optional.
-
#partner ⇒ String
Optional.
-
#partner_permissions ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions
Permissions granted to the AW Partner SA account for the customer workload Corresponds to the JSON property
partnerPermissions. -
#partner_services_billing_account ⇒ String
Optional.
-
#provisioned_resources_parent ⇒ String
Input only.
-
#resource_monitoring_enabled ⇒ Boolean
(also: #resource_monitoring_enabled?)
Output only.
-
#resource_settings ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadResourceSettings>
Input only.
-
#resources ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadResourceInfo>
Output only.
-
#saa_enrollment_response ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse
Signed Access Approvals (SAA) enrollment response.
-
#violation_notifications_enabled ⇒ Boolean
(also: #violation_notifications_enabled?)
Optional.
-
#workload_options ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions
Options to be set for the given created workload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1Workload
constructor
A new instance of GoogleCloudAssuredworkloadsV1Workload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAssuredworkloadsV1Workload
Returns a new instance of GoogleCloudAssuredworkloadsV1Workload.
1118 1119 1120 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_account ⇒ String
Optional. The billing account used for the resources which are direct children
of workload. This billing account is initially associated with the resources
created as part of Workload creation. After the initial creation of these
resources, the customer can change the assigned billing account. The resource
name has the form billingAccounts/billing_account_id`. For example,
billingAccounts/012345-567890-ABCDEF.
Corresponds to the JSON propertybillingAccount`
978 979 980 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 978 def billing_account @billing_account end |
#compliance_regime ⇒ String
Required. Immutable. Compliance Regime associated with this workload.
Corresponds to the JSON property complianceRegime
983 984 985 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 983 def compliance_regime @compliance_regime end |
#compliance_status ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus
Represents the Compliance Status of this workload
Corresponds to the JSON property complianceStatus
988 989 990 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 988 def compliance_status @compliance_status end |
#compliant_but_disallowed_services ⇒ Array<String>
Output only. Urls for services which are compliant for this Assured Workload,
but which are currently disallowed by the ResourceUsageRestriction org policy.
Invoke RestrictAllowedResources endpoint to allow your project developers to
use these services in their environment.
Corresponds to the JSON property compliantButDisallowedServices
996 997 998 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 996 def compliant_but_disallowed_services @compliant_but_disallowed_services end |
#create_time ⇒ String
Output only. Immutable. The Workload creation timestamp.
Corresponds to the JSON property createTime
1001 1002 1003 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1001 def create_time @create_time end |
#display_name ⇒ String
Required. The user-assigned display name of the Workload. When present it must
be between 4 to 30 characters. Allowed characters are: lowercase and uppercase
letters, numbers, hyphen, and spaces. Example: My Workload
Corresponds to the JSON property displayName
1008 1009 1010 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1008 def display_name @display_name end |
#ekm_provisioning_response ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse
External key management systems(EKM) Provisioning response
Corresponds to the JSON property ekmProvisioningResponse
1013 1014 1015 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1013 def ekm_provisioning_response @ekm_provisioning_response end |
#enable_sovereign_controls ⇒ Boolean Also known as: enable_sovereign_controls?
Optional. Indicates the sovereignty status of the given workload. Currently
meant to be used by Europe/Canada customers.
Corresponds to the JSON property enableSovereignControls
1019 1020 1021 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1019 def enable_sovereign_controls @enable_sovereign_controls end |
#etag ⇒ String
Optional. ETag of the workload, it is calculated on the basis of the Workload
contents. It will be used in Update & Delete operations.
Corresponds to the JSON property etag
1026 1027 1028 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1026 def etag @etag end |
#kaj_enrollment_state ⇒ String
Output only. Represents the KAJ enrollment state of the given workload.
Corresponds to the JSON property kajEnrollmentState
1031 1032 1033 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1031 def kaj_enrollment_state @kaj_enrollment_state end |
#kms_settings ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadKmsSettings
Settings specific to the Key Management Service.
Corresponds to the JSON property kmsSettings
1036 1037 1038 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1036 def kms_settings @kms_settings end |
#labels ⇒ Hash<String,String>
Optional. Labels applied to the workload.
Corresponds to the JSON property labels
1041 1042 1043 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1041 def labels @labels end |
#name ⇒ String
Optional. The resource name of the workload. Format: organizations/
organization/locations/location/workloads/workload Read-only.
Corresponds to the JSON property name
1047 1048 1049 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1047 def name @name end |
#partner ⇒ String
Optional. Partner regime associated with this workload.
Corresponds to the JSON property partner
1052 1053 1054 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1052 def partner @partner end |
#partner_permissions ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions
Permissions granted to the AW Partner SA account for the customer workload
Corresponds to the JSON property partnerPermissions
1057 1058 1059 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1057 def @partner_permissions end |
#partner_services_billing_account ⇒ String
Optional. Billing account necessary for purchasing services from Sovereign
Partners. This field is required for creating SIA/PSN/CNTXT partner workloads.
The caller should have 'billing.resourceAssociations.create' IAM permission on
this billing-account. The format of this string is billingAccounts/AAAAAA-
BBBBBB-CCCCCC
Corresponds to the JSON property partnerServicesBillingAccount
1066 1067 1068 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1066 def partner_services_billing_account @partner_services_billing_account end |
#provisioned_resources_parent ⇒ String
Input only. The parent resource for the resources managed by this Assured
Workload. May be either empty or a folder resource which is a child of the
Workload parent. If not specified all resources are created under the parent
organization. Format: folders/folder_id
Corresponds to the JSON property provisionedResourcesParent
1074 1075 1076 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1074 def provisioned_resources_parent @provisioned_resources_parent end |
#resource_monitoring_enabled ⇒ Boolean Also known as: resource_monitoring_enabled?
Output only. Indicates whether resource monitoring is enabled for workload or
not. It is true when Resource feed is subscribed to AWM topic and AWM Service
Agent Role is binded to AW Service Account for resource Assured workload.
Corresponds to the JSON property resourceMonitoringEnabled
1081 1082 1083 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1081 def resource_monitoring_enabled @resource_monitoring_enabled end |
#resource_settings ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadResourceSettings>
Input only. Resource properties that are used to customize workload resources.
These properties (such as custom project id) will be used to create workload
resources if possible. This field is optional.
Corresponds to the JSON property resourceSettings
1089 1090 1091 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1089 def resource_settings @resource_settings end |
#resources ⇒ Array<Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadResourceInfo>
Output only. The resources associated with this workload. These resources will
be created when creating the workload. If any of the projects already exist,
the workload creation will fail. Always read only.
Corresponds to the JSON property resources
1096 1097 1098 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1096 def resources @resources end |
#saa_enrollment_response ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse
Signed Access Approvals (SAA) enrollment response.
Corresponds to the JSON property saaEnrollmentResponse
1101 1102 1103 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1101 def saa_enrollment_response @saa_enrollment_response end |
#violation_notifications_enabled ⇒ Boolean Also known as: violation_notifications_enabled?
Optional. Indicates whether the e-mail notification for a violation is enabled
for a workload. This value will be by default True, and if not present will be
considered as true. This should only be updated via updateWorkload call. Any
Changes to this field during the createWorkload call will not be honored. This
will always be true while creating the workload.
Corresponds to the JSON property violationNotificationsEnabled
1110 1111 1112 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1110 def violation_notifications_enabled @violation_notifications_enabled end |
#workload_options ⇒ Google::Apis::AssuredworkloadsV1::GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions
Options to be set for the given created workload.
Corresponds to the JSON property workloadOptions
1116 1117 1118 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1116 def @workload_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 |
# File 'lib/google/apis/assuredworkloads_v1/classes.rb', line 1123 def update!(**args) @billing_account = args[:billing_account] if args.key?(:billing_account) @compliance_regime = args[:compliance_regime] if args.key?(:compliance_regime) @compliance_status = args[:compliance_status] if args.key?(:compliance_status) @compliant_but_disallowed_services = args[:compliant_but_disallowed_services] if args.key?(:compliant_but_disallowed_services) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @ekm_provisioning_response = args[:ekm_provisioning_response] if args.key?(:ekm_provisioning_response) @enable_sovereign_controls = args[:enable_sovereign_controls] if args.key?(:enable_sovereign_controls) @etag = args[:etag] if args.key?(:etag) @kaj_enrollment_state = args[:kaj_enrollment_state] if args.key?(:kaj_enrollment_state) @kms_settings = args[:kms_settings] if args.key?(:kms_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @partner = args[:partner] if args.key?(:partner) @partner_permissions = args[:partner_permissions] if args.key?(:partner_permissions) @partner_services_billing_account = args[:partner_services_billing_account] if args.key?(:partner_services_billing_account) @provisioned_resources_parent = args[:provisioned_resources_parent] if args.key?(:provisioned_resources_parent) @resource_monitoring_enabled = args[:resource_monitoring_enabled] if args.key?(:resource_monitoring_enabled) @resource_settings = args[:resource_settings] if args.key?(:resource_settings) @resources = args[:resources] if args.key?(:resources) @saa_enrollment_response = args[:saa_enrollment_response] if args.key?(:saa_enrollment_response) @violation_notifications_enabled = args[:violation_notifications_enabled] if args.key?(:violation_notifications_enabled) @workload_options = args[:workload_options] if args.key?(:workload_options) end |